==> geoengine-0.1.1.tar.gz: lib/geoengine.dart <==
// ignore_for_file: implementation_imports
library geoengine;

import 'package:advance_math/advance_math.dart' hide Point;
import 'package:geoxml/geoxml.dart';

import 'package:proj4dart/proj4dart.dart';
import 'package:proj4dart/src/common/datum_utils.dart' as datum_utils;
import 'package:proj4dart/src/common/utils.dart' as utils;
import 'package:proj4dart/src/constants/values.dart' as consts;
import 'package:mgrs_dart/mgrs_dart.dart' as mgrs_dart;

export 'package:geoxml/geoxml.dart';
export 'package:proj4dart/proj4dart.dart' hide Point;

part 'src/point/x_point.dart';
part 'src/point/mgrs.dart';
part 'src/point/latlng.dart';
part 'src/point/utm.dart';
part 'src/point/x_point_part_enum.dart';

part 'src/coordinate_systems/trans_engine.dart';
part 'src/coordinate_systems/utm_zones.dart';
part 'src/coordinate_systems/enums.dart';

part 'src/coordinate_systems/ellipsoid/ellipsoid.dart';
part 'src/coordinate_systems/ellipsoid/utm_ellipsoid.dart';

part 'src/coordinate_systems/prime_meridian.dart';
part 'src/coordinate_systems/info.dart';
part 'src/coordinate_systems/crs.dart';

part 'src/coordinate_systems/axis_info/axis_info.dart';
part 'src/coordinate_systems/axis_info/axis_orientation.dart';

part 'src/coordinate_systems/units/angular.dart';
part 'src/coordinate_systems/units/linear.dart';

part 'src/julian_date/julian_date.dart';

part 'src/distance/enum.dart';
part 'src/distance/distance.dart';
part 'src/distance/bearing.dart';

part 'src/least_square/least_squares_adjustment.dart';
part 'src/least_square/scaling_method.dart';

==> geoengine-0.1.2.tar.gz: lib/geoengine.dart <==
// ignore_for_file: implementation_imports
library geoengine;

import 'package:advance_math/advance_math.dart' hide Point;
import 'package:geoxml/geoxml.dart';

import 'package:proj4dart/proj4dart.dart';
import 'package:proj4dart/src/common/datum_utils.dart' as datum_utils;
import 'package:proj4dart/src/common/utils.dart' as utils;
import 'package:proj4dart/src/constants/values.dart' as consts;
import 'package:mgrs_dart/mgrs_dart.dart' as mgrs_dart;

export 'package:geoxml/geoxml.dart';
export 'package:proj4dart/proj4dart.dart' hide Point;

part 'src/points/x_point.dart';
part 'src/points/mgrs.dart';
part 'src/points/latlng.dart';
part 'src/points/utm.dart';
part 'src/points/x_point_part_enum.dart';

part 'src/coordinate_systems/trans_engine.dart';
part 'src/coordinate_systems/utm_zones.dart';
part 'src/coordinate_systems/enums.dart';

part 'src/coordinate_systems/ellipsoid/ellipsoid.dart';
part 'src/coordinate_systems/ellipsoid/utm_ellipsoid.dart';

part 'src/coordinate_systems/prime_meridian.dart';
part 'src/coordinate_systems/info.dart';
part 'src/coordinate_systems/crs.dart';

part 'src/coordinate_systems/axis_info/axis_info.dart';
part 'src/coordinate_systems/axis_info/axis_orientation.dart';

part 'src/coordinate_systems/units/angular.dart';
part 'src/coordinate_systems/units/linear.dart';

part 'src/julian_date/julian_date.dart';

part 'src/distance/enum.dart';
part 'src/distance/distance.dart';
part 'src/distance/bearing.dart';

part 'src/least_square/least_squares_adjustment.dart';
part 'src/least_square/scaling_method.dart';
